@@ -156,17 +156,22 @@ def get_corpus(dataset_name='wikipedia', config_name='20200501.en'):
     # built-in corpora
     corpora = {
         'minipedia': 'https://www.dropbox.com/s/eal65nd5a193pmk/minipedia.npz?dl=1',
-        'neurips': 'https://www.dropbox.com/s/w1t6onmdvt2mavb/neurips.npz?dl=1',
+        'neurips': 'https://www.dropbox.com/s/i32dycxr0qa90wx/neurips.npz?dl=1',
         'sotus': 'https://www.dropbox.com/s/e2qfw8tkmxp6bad/sotus.npz?dl=1',
-        'khan': 'https://www.dropbox.com/s/fz3p2zx9csih0xh/khan.npz?dl=1'}
+        'khan': 'https://www.dropbox.com/s/ieztnyhao2ejo48/khan.npz?dl=1'}
 
     if dataset_name in corpora.keys():
-        print(f'loading corpus: {dataset_name}', end='...')
-        corpus = load(corpora[dataset_name], dtype='numpy')['corpus']
-        print('done!')
-
-        preloaded_corpora[key] = corpus
-        return corpus
+        print(f'loading corpus: {dataset_name}', end='')
+        data = load(corpora[dataset_name], dtype='numpy')
+        try:
+            corpus = data['corpus']
+            print('...done!', end='')
+            preloaded_corpora[key] = corpus
+            return corpus
+        finally:
+            # ensure NpzFile is closed
+            data.close()
+        print('')
 
     # Hugging-Face Corpus
     try:
@@ -175,7 +180,7 @@ def get_corpus(dataset_name='wikipedia', config_name='20200501.en'):
         raise RuntimeError(f'Corpus not found: {dataset_name}.  Available corpora: {", ".join(list_datasets())}')
     except ValueError:
         raise RuntimeError(f'Configuration for {dataset_name} corpus not found: {config_name}. '
-                           f'Available configurations: {", ".join(get_dataset_config_names(data_name))}')
+                           f'Available configurations: {", ".join(get_dataset_config_names(dataset_name))}')
 
     corpus = []
     content_keys = ['text', 'content']
@@ -291,7 +296,7 @@ def apply_text_model(x, text, *args, mode='fit_transform', return_model=False, *
         return transformed_text
     elif is_hugging_face_model(model):
         warnings.simplefilter('ignore')
-        
+
         if mode == 'fit':  # do nothing-- just return the un-transformed text and original model
             if return_model:
                 return text, {'model': model, 'args': args, 'kwargs': kwargs}
